@@ -28,6 +28,7 @@ import time
 
 from . import YES, NO
 from vdsm.tool import service
+from vdsm.common import cmdutils
 from vdsm.common import commands
 from vdsm import constants
 
@@ -296,8 +297,12 @@ def configure():
             os.unlink(f.name)
             raise
 
-    # Flush all unused multipath device maps
-    commands.execCmd([constants.EXT_MULTIPATH, "-F"])
+    # Flush all unused multipath device maps. 'multipath'
+    # returns 1 if any of the devices is in use and unable to flush.
+    try:
+        commands.run([constants.EXT_MULTIPATH, "-F"])
+    except cmdutils.Error:
+        pass
 
     try:
         service.service_reload("multipathd")
