@@ -323,11 +323,6 @@ class FakeVolumeManifest(object):
     def volumePath(self):
         return '/a/b/c'
 
-    @classmethod
-    @recorded
-    def formatMetadata(cls, *args):
-        pass
-
     @classmethod
     @recorded
     def _putMetadata(cls, *args):
@@ -360,10 +355,6 @@ class FakeVolumeManifest(object):
     def getMetaParam(self, key):
         pass
 
-    @recorded
-    def setMetadata(self, meta, metaId=None):
-        pass
-
     @recorded
     def getParent(self):
         pass
@@ -545,7 +536,7 @@ class FakeVolumeManifest(object):
 class FakeBlockVolumeManifest(FakeVolumeManifest):
 
     @recorded
-    def getMetaOffset(self):
+    def getMetaSlot(self):
         pass
 
     @recorded
@@ -596,7 +587,7 @@ class FakeFileVolumeManifest(FakeVolumeManifest):
         self.oop = 'oop'
 
     @recorded
-    def _getMetaVolumePath(self, vol_path=None):
+    def getMetaVolumePath(self, vol_path=None):
         pass
 
     @classmethod
@@ -609,7 +600,7 @@ class FakeFileVolumeManifest(FakeVolumeManifest):
         pass
 
     @recorded
-    def _getLeaseVolumePath(self, vol_path):
+    def getLeaseVolumePath(self, vol_path):
         pass
 
     @recorded
@@ -814,7 +805,6 @@ class VolumeTestMixin(object):
         ['getMetadataId', 0],
         ['getMetadata', 1],
         ['getMetaParam', 1],
-        ['setMetadata', 2],
         ['getParent', 0],
         ['setLeaf', 0],
         ['isLeaf', 0],
@@ -859,7 +849,6 @@ class VolumeTestMixin(object):
         self.checker.check_method_call(fn, nargs)
 
     @permutations([
-        ['formatMetadata', 1],
         ['_putMetadata', 2],
         ['createMetadata', 2],
         ['newMetadata', 11],
@@ -879,7 +868,7 @@ class TestBlockVolume(VolumeTestMixin, VdsmTestCase):
         self.checker = RedirectionChecker(self.volume, '_manifest')
 
     @permutations([
-        ['getMetaOffset', 0],
+        ['getMetaSlot', 0],
         ['getParentMeta', 0],
         ['getParentTag', 0],
         ['getVolumeTag', 1],
@@ -914,10 +903,10 @@ class TestFileVolume(VolumeTestMixin, VdsmTestCase):
     def test_file_property(self, prop, val):
         self.assertEqual(getattr(self.volume, prop), val)
 
-    # TODO: Test _getLeaseVolumePath with no arguments
+    # TODO: Test getLeaseVolumePath with no arguments
     @permutations([
-        ['_getMetaVolumePath', 1],
-        ['_getLeaseVolumePath', 1],
+        ['getMetaVolumePath', 1],
+        ['getLeaseVolumePath', 1],
         ['_setrw', 1],
         ['removeMetadata', 0],
     ])
